@@ -7,6 +7,6 @@ test_that("get_details runs successfully", {
   google_token <- readRDS("token_file.rds")$google_token
   options(google_token=google_token)
 
-  get_info <- get_details(video_id="N708P-A45D0")
+  get_info <- get_video_details(video_id="N708P-A45D0")
   expect_that(get_info, is_a("list"))
 })
\ No newline at end of file
