@@ -8,5 +8,5 @@ test_that("list_channel_activities runs successfully", {
   options(google_token=google_token)
 
   get_info <- list_channel_activities(filter = c(channel_id="UCRw8bIz2wMLmfgAgWm903cA"))
-  expect_that(get_info, is_a("list"))
+  expect_that(get_info, is_a("data.frame"))
 })
\ No newline at end of file
